Enum Idx
Source #[repr(u8)]
pub enum Idx {
Zero = 0,
One = 1,
Two = 2,
}
Create triple index from u8 value.
Panics
Panics if value is not 0, 1 or 2.
Create triple index from u8 value without checking for bounds.
Safety
The caller must ensure that value is 0, 1 or 2.
Returns bits representation of the index.
Return other index.
Call it again to get one another index.
Calling it 3rd time will return the same index.
Performs copy-assignment from
source.
Read more
Formats the value using the given formatter.
Read more
Returns the “default value” for a type.
Read more
Tests for self and other values to be equal, and is used by ==.
Tests for !=. The default implementation is almost always sufficient,
and should not be overridden without very good reason.
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
🔬This is a nightly-only experimental API. (clone_to_uninit)
Performs copy-assignment from
self to
dest.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
From<T> for U chooses to do.
The resulting type after obtaining ownership.
Creates owned data from borrowed data, usually by cloning.
Read more
Uses borrowed data to replace owned data, usually by cloning.
Read more
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.